@@ -216,8 +216,9 @@ class BaremetalStandaloneManager(bm.BaremetalScenarioTest,
                 return False
             return True
 
-        if (not test_utils.call_until_true(_try_to_associate_instance,
-            duration=CONF.baremetal.association_timeout, sleep_for=1)):
+        if (not test_utils.call_until_true(
+                _try_to_associate_instance,
+                duration=CONF.baremetal.association_timeout, sleep_for=1)):
             msg = ('Timed out waiting to associate instance to ironic node '
                    'uuid %s' % instance_uuid)
             raise lib_exc.TimeoutException(msg)
@@ -571,32 +572,53 @@ class BaremetalStandaloneScenarioTest(BaremetalStandaloneManager):
         self.assertTrue(self.ping_ip_address(self.node_ip,
                                              should_succeed=should_succeed))
 
-    def build_raid_and_verify_node(self, config=None, clean_steps=None):
+    def build_raid_and_verify_node(self, config=None, deploy_time=False):
         config = config or self.raid_config
-        clean_steps = clean_steps or [
-            {
-                "interface": "raid",
-                "step": "delete_configuration"
-            },
-            # NOTE(dtantsur): software RAID building fails if any
-            # partitions exist on holder devices.
-            {
-                "interface": "deploy",
-                "step": "erase_devices_metadata"
-            },
-            {
-                "interface": "raid",
-                "step": "create_configuration"
-            }
-        ]
-
-        self.baremetal_client.set_node_raid_config(self.node['uuid'], config)
-        self.manual_cleaning(self.node, clean_steps=clean_steps)
+        if deploy_time:
+            steps = [
+                {
+                    "interface": "deploy",
+                    "step": "erase_devices_metadata",
+                    "priority": 98,
+                    "args": {},
+                },
+                {
+                    "interface": "raid",
+                    "step": "apply_configuration",
+                    "priority": 97,
+                    "args": {"raid_config": config},
+                }
+            ]
+            self.baremetal_client.create_deploy_template(
+                'CUSTOM_RAID', steps=steps)
+            self.baremetal_client.add_node_trait(self.node['uuid'],
+                                                 'CUSTOM_RAID')
+        else:
+            steps = [
+                {
+                    "interface": "raid",
+                    "step": "delete_configuration"
+                },
+                {
+                    "interface": "deploy",
+                    "step": "erase_devices_metadata",
+                },
+                {
+                    "interface": "raid",
+                    "step": "create_configuration",
+                }
+            ]
+            self.baremetal_client.set_node_raid_config(self.node['uuid'],
+                                                       config)
+            self.manual_cleaning(self.node, clean_steps=steps)
 
         # NOTE(dtantsur): this is not required, but it allows us to check that
         # the RAID device was in fact created and is used for deployment.
         patch = [{'path': '/properties/root_device',
                   'op': 'add', 'value': {'name': '/dev/md0'}}]
+        if deploy_time:
+            patch.append({'path': '/instance_info/traits',
+                          'op': 'add', 'value': ['CUSTOM_RAID']})
         self.update_node(self.node['uuid'], patch=patch)
         # NOTE(dtantsur): apparently cirros cannot boot from md devices :(
         # So we only move the node to active (verifying deployment).
@@ -627,3 +649,58 @@ class BaremetalStandaloneScenarioTest(BaremetalStandaloneManager):
         self.unrescue_node(self.node['uuid'])
         self.assertTrue(self.ping_ip_address(self.node_ip,
                                              should_succeed=True))
+
+    @classmethod
+    def boot_node_ramdisk(cls, ramdisk_ref, iso=False):
+        """Boot ironic using a ramdisk node.
+
+        The following actions are executed:
+          * Create/Pick networks to boot node in.
+          * Create Neutron port and attach it to node.
+          * Update node image_source.
+          * Deploy node.
+          * Wait until node is deployed.
+
+        :param ramdisk_ref: Reference to user image or ramdisk to boot
+                            the node with.
+        :param iso: Boolean, default False, to indicate if the image ref
+                    us actually an ISO image.
+        """
+        if ramdisk_ref is None:
+            ramdisk_ref = cls.image_ref
+
+        network, subnet, router = cls.create_networks()
+        n_port = cls.create_neutron_port(network_id=network['id'])
+        cls.vif_attach(node_id=cls.node['uuid'], vif_id=n_port['id'])
+        if iso:
+            patch_path = '/instance_info/boot_iso'
+        else:
+            # NOTE(TheJulia): The non ISO ramdisk path supports this
+            # and it being here makes it VERY easy for us to add a test
+            # of just a kernel/ramdisk loading from glance at some point.
+            patch_path = '/instance_info/image_source'
+        patch = [{'path': patch_path,
+                  'op': 'add',
+                  'value': ramdisk_ref}]
+        cls.update_node(cls.node['uuid'], patch=patch)
+        cls.set_node_provision_state(cls.node['uuid'], 'active')
+        if CONF.validation.connect_method == 'floating':
+            cls.node_ip = cls.add_floatingip_to_node(cls.node['uuid'])
+        elif CONF.validation.connect_method == 'fixed':
+            cls.node_ip = cls.get_server_ip(cls.node['uuid'])
+        else:
+            m = ('Configuration option "[validation]/connect_method" '
+                 'must be set.')
+            raise lib_exc.InvalidConfiguration(m)
+        cls.wait_power_state(cls.node['uuid'],
+                             bm.BaremetalPowerStates.POWER_ON)
+        cls.wait_provisioning_state(cls.node['uuid'],
+                                    bm.BaremetalProvisionStates.ACTIVE,
+                                    timeout=CONF.baremetal.active_timeout,
+                                    interval=30)
+
+    def boot_and_verify_ramdisk_node(self, ramdisk_ref=None, iso=False,
+                                     should_succeed=True):
+        self.boot_node_ramdisk(ramdisk_ref, iso)
+        self.assertTrue(self.ping_ip_address(self.node_ip,
+                                             should_succeed=should_succeed))
